@@ -37,7 +37,7 @@ from calculate.lib.encrypt import get_shadow_hash, get_grub_hash
 from calculate.core.server.admin import Admins
 import calculate.lib.cl_ini_parser as cl_ini_parser
 from calculate.lib.cl_template import SystemIni
-
+from .distr import DistributiveError
 from calculate.lib.cl_lang import setLocalTranslate, _
 
 setLocalTranslate('cl_install3', sys.modules[__name__])
@@ -729,7 +729,13 @@ class VariableOsNvidiaMask(ReadonlyVariable):
                                      'usr/portage/eclass/nvidia-driver.eclass')
             if not os.access(nvidiaeclass, os.R_OK):
                 return ""
-            if not nvidiacards:
+            #TODO investigate
+            #there used to be a typo - nvidiacards instead of... ?
+            # (nvidiacards wasn't defined)
+            # if not nvidiacards:
+            #     return ""
+
+            if not nvidiaeclass:
                 return ""
             cardsid = self.get_cards_id()
             if not cardsid:
